@@ -38,5 +38,13 @@ class TestQTTimeRange (TestCase):
         o = QTIntersectionTimeRange(rng, rng2)
         self.assertIsInstance(o, QTTimeRange)
 
+        s = QTStringFromTimeRange(rng)
+        self.assertIsInstance(s, unicode)
+
+        t = QTTimeRangeFromString(s)
+        self.assertIsInstance(t, QTTimeRange)
+
+        self.assertTrue(QTEqualTimeRanges(t, rng))
+
 if __name__ == "__main__":
     main()
